## Anonfiles.com direct link generator

Generate direct link for downloading file from anonfiles.com

## Requirements

At least Python 3, **beautifulsoup4**, and **requests** as well

## Usage

```
import anonfiles-directlink as d

link = 'some anonfiles link'
download_link = d.direct_link(link)
print(direct_link)
```